@@ -21,26 +21,21 @@ class KGAPIDRIVE_EXPORT DrivesCreateJob : public KGAPI2::CreateJob
 {
     Q_OBJECT
 
-  public:
-    DrivesCreateJob(const QString &requestId,
-                            const DrivesPtr &drives,
-                            const AccountPtr &account, QObject *parent = nullptr);
-    DrivesCreateJob(const QString &requestId,
-                            const DrivesList &drives,
-                            const AccountPtr &account, QObject *parent = nullptr);
+public:
+    DrivesCreateJob(const QString &requestId, const DrivesPtr &drives, const AccountPtr &account, QObject *parent = nullptr);
+    DrivesCreateJob(const QString &requestId, const DrivesList &drives, const AccountPtr &account, QObject *parent = nullptr);
     ~DrivesCreateJob() override;
 
     /**
      * @brief Returns the requestId used in this create request.
      */
-    QString requestId() const;
+    Q_REQUIRED_RESULT QString requestId() const;
 
-  protected:
+protected:
     void start() override;
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                                const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
     QScopedPointer<Private> d;
     friend class Private;
@@ -49,4 +44,3 @@ class KGAPIDRIVE_EXPORT DrivesCreateJob : public KGAPI2::CreateJob
 } // namespace Drive
 
 } // namespace KGAPI2
-
